/* Copyright 2024 Collabora Ltd.
 * SPDX-License-Identifier: MIT
 */

/* This file is autogenerated by nil_format_table_gen.py. DO NOT EDIT! */

#include "nil_format_table.h"

#include "cl9097.h"
#include "cl9097tex.h"
#include "clb097.h"
#include "clb097tex.h"
#include "clb197.h"
#include "clb197tex.h"
#include "clcb97.h"
#include "clcb97tex.h"

const struct nil_format_info nil_format_table[PIPE_FORMAT_COUNT] = {
    [PIPE_FORMAT_R1_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R1,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_A4B4G4R4_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A4B4G4R4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A4R4G4B4_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A4B4G4R4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_B4G4R4A4_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A4B4G4R4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_B4G4R4X4_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A4B4G4R4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R4G4B4A4_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A4B4G4R4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R4G4B4X4_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A4B4G4R4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_B5G6R5_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_R5G6B5,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT | NIL_FORMAT_SUPPORTS_SCANOUT_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_B5G6R5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R5G6B5_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_B5G6R5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R5G5B5A1_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A1B5G5R5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_B5G5R5A1_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_A1R5G5B5,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT | NIL_FORMAT_SUPPORTS_SCANOUT_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A1B5G5R5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_B5G5R5X1_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_X1R5G5B5,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT | NIL_FORMAT_SUPPORTS_SCANOUT_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A1B5G5R5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_R8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R8_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RN8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R8_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R8_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R8_SRGB] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R8G8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_G8R8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R8G8_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_GN8RN8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R8G8_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_GS8RS8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R8G8_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_GU8RU8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_B8G8R8A8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_A8R8G8B8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_SCANOUT_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_B8G8R8X8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_X8R8G8B8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT | NIL_FORMAT_SUPPORTS_SCANOUT_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_B8G8R8A8_SRGB] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_A8RL8GL8BL8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT | NIL_FORMAT_SUPPORTS_SCANOUT_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_B8G8R8X8_SRGB] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_X8RL8GL8BL8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT | NIL_FORMAT_SUPPORTS_SCANOUT_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R8G8B8A8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_A8B8G8R8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R8G8B8X8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_X8B8G8R8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R8G8B8A8_SRGB] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_A8BL8GL8RL8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R8G8B8X8_SRGB] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_X8BL8GL8RL8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R8G8B8A8_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_AN8BN8GN8RN8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R8G8B8A8_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_AS8BS8GS8RS8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R8G8B8A8_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_AU8BU8GU8RU8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R8G8B8X8_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_AN8BN8GN8RN8,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R8G8B8X8_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_AS8BS8GS8RS8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R8G8B8X8_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_AU8BU8GU8RU8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R9G9B9E5_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_E5B9G9R9_SHAREDEXP,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R10G10B10A2_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_A2B10G10R10,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_SCANOUT_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A2B10G10R10,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R10G10B10X2_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_A2B10G10R10,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A2B10G10R10,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_B10G10R10A2_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_A2R10G10B10,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A2B10G10R10,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_B10G10R10X2_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_A2R10G10B10,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A2B10G10R10,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R10G10B10A2_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_AU2BU10GU10RU10,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A2B10G10R10,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_B10G10R10A2_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A2B10G10R10,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R11G11B10_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_BF10GF11RF11,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_BF10GF11RF11,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R16_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RF16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R16_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_R16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R16_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RN16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R16_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R16_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R16G16_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RF16_GF16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R16G16_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_R16_G16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R16G16_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RN16_GN16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R16G16_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS16_GS16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R16G16_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU16_GU16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R16G16B16A16_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RF16_GF16_BF16_AF16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16_B16_A16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R16G16B16A16_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_R16_G16_B16_A16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16_B16_A16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R16G16B16A16_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RN16_GN16_BN16_AN16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16_B16_A16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R16G16B16A16_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS16_GS16_BS16_AS16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16_B16_A16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R16G16B16A16_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU16_GU16_BU16_AU16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16_B16_A16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R16G16B16X16_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RF16_GF16_BF16_X16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16_B16_A16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R16G16B16X16_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_R16_G16_B16_A16,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16_B16_A16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R16G16B16X16_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RN16_GN16_BN16_AN16,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16_B16_A16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R16G16B16X16_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS16_GS16_BS16_AS16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16_B16_A16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R16G16B16X16_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU16_GU16_BU16_AU16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16_B16_A16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R32_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RF32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R32_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R32_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R32_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R32_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R32G32_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RF32_GF32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R32G32_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R32G32_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R32G32_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS32_GS32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R32G32_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU32_GU32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R32G32B32_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32_B32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R32G32B32_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32_B32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R32G32B32_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32_B32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R32G32B32A32_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RF32_GF32_BF32_AF32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32_B32_A32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R32G32B32A32_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32_B32_A32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R32G32B32A32_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32_B32_A32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R32G32B32A32_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS32_GS32_BS32_AS32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32_B32_A32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R32G32B32A32_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU32_GU32_BU32_AU32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32_B32_A32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_R32G32B32X32_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RF32_GF32_BF32_X32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32_B32_A32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R32G32B32X32_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS32_GS32_BS32_X32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32_B32_A32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R32G32B32X32_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU32_GU32_BU32_X32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32_B32_A32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R64_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_R64_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_Z16_UNORM] = {
        .czt = NVB097_SET_ZT_FORMAT_V_Z16,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_DEPTH_STENCIL_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_Z16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_Z32_FLOAT] = {
        .czt = NV9097_SET_ZT_FORMAT_V_ZF32,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_DEPTH_STENCIL_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_ZF32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_Z24X8_UNORM] = {
        .czt = NV9097_SET_ZT_FORMAT_V_X8Z24,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_DEPTH_STENCIL_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_ZS,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_X8Z24,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_X8Z24_UNORM] = {
        .czt = NV9097_SET_ZT_FORMAT_V_Z24S8,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_DEPTH_STENCIL_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SZ,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_Z24S8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_Z24_UNORM_S8_UINT] = {
        .czt = NV9097_SET_ZT_FORMAT_V_S8Z24,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_DEPTH_STENCIL_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_ZS,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_S8Z24,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_S8_UINT_Z24_UNORM] = {
        .czt = NV9097_SET_ZT_FORMAT_V_Z24S8,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_DEPTH_STENCIL_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SZ,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_Z24S8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_Z32_FLOAT_S8X24_UINT] = {
        .czt = NV9097_SET_ZT_FORMAT_V_ZF32_X24S8,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_DEPTH_STENCIL_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_ZFS,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_ZF32_X24S8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_S8_UINT] = {
        .czt = NVB197_SET_ZT_FORMAT_V_S8,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_DEPTH_STENCIL_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NVB197_TEXHEAD_BL_COMPONENTS_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_X24S8_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_ZS,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8R24,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_S8X24_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SZ,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G24R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_X32_S8X24_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_ZFS,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_B24G8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_L8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_R8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_L8_SRGB] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_L8_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RN8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_L8_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_L8_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_L16_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_R16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_L16_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RN16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_L16_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RF16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_L16_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_L16_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_L32_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RF32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_L32_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_L32_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_INT,
        },
    },
    [PIPE_FORMAT_I8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_R8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_I8_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RN8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_I8_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_I8_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_I16_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_R16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_I16_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RN16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_I16_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RF16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_I16_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_I16_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU16,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_I32_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RF32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_I32_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RS32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_I32_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_RU32,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_A8,
        .support = NIL_FORMAT_SUPPORTS_RENDER_BIT | NIL_FORMAT_SUPPORTS_TEXTURE_BIT | NIL_FORMAT_SUPPORTS_BUFFER_BIT | NIL_FORMAT_SUPPORTS_STORAGE_BIT | NIL_FORMAT_SUPPORTS_ALPHA_BLEND_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A8_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A8_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A8_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A16_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A16_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A16_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_AF16,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A16_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A16_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A32_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_AF32,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A32_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A32_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_L4A4_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G4R4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L8A8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L8A8_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L8A8_SRGB] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L8A8_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L8A8_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L16A16_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L16A16_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L16A16_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L16A16_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L16A16_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R16_G16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L32A32_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L32A32_SINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_L32A32_UINT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UINT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_R32_G32,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UINT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_R4A4_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G4R4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_R8A8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_A4R4_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G4R4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_A8R8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
        },
    },
    [PIPE_FORMAT_R8G8_B8G8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_G8R8_B8R8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_G8R8_G8B8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_B8G8R8G8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R8G8_R8B8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_B8G8R8G8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_G8B8_G8R8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_B8G8R8G8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_B8G8_R8G8_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_G8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R8SG8SB8UX8U_NORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_A8B8G8R8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_R5SG5SB6U_NORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_B6G5R5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_DXT1_RGB] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXT1,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_DXT1_SRGB] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXT1,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_DXT1_RGBA] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXT1,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_DXT1_SRGBA] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXT1,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_DXT3_RGBA] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXT23,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_DXT3_SRGBA] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXT23,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_DXT5_RGBA] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXT45,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_DXT5_SRGBA] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXT45,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_RGTC1_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXN1,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_RGTC1_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXN1,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_RGTC2_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXN2,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_RGTC2_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXN2,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_LATC1_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXN1,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_LATC1_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXN1,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_LATC2_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXN2,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_LATC2_SNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_DXN2,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
        },
    },
    [PIPE_FORMAT_BPTC_RGBA_UNORM] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_BC7U,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_BPTC_SRGBA] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_BC7U,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_BPTC_RGB_FLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_BC6H_SF16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_BPTC_RGB_UFLOAT] = {
        .czt = NV9097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_FLOAT,
        .tic = {
            .comp_sizes = NV9097_TEXHEADV2_0_COMPONENT_SIZES_BC6H_UF16,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_FLOAT,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_ETC1_RGB8] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ETC2_RGB,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_ETC2_RGB8] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ETC2_RGB,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_ETC2_SRGB8] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ETC2_RGB,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_ETC2_RGB8A1] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ETC2_RGB_PTA,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ETC2_SRGB8A1] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ETC2_RGB_PTA,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ETC2_RGBA8] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ETC2_RGBA,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ETC2_SRGBA8] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ETC2_RGBA,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ETC2_R11_UNORM] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_EAC,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_ETC2_R11_SNORM] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_EAC,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_ETC2_RG11_UNORM] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_EACX2,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_ETC2_RG11_SNORM] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_SNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_EACX2,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_SNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ZERO,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_ONE_FLOAT,
        },
    },
    [PIPE_FORMAT_ASTC_4x4] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_4X4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_5x4] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_5X4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_5x5] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_5X5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_6x5] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_6X5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_6x6] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_6X6,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_8x5] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_8X5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_8x6] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_8X6,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_8x8] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_8X8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_10x5] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_10X5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_10x6] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_10X6,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_10x8] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_10X8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_10x10] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_10X10,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_12x10] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_12X10,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_12x12] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_12X12,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_4x4_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_4X4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_5x4_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_5X4,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_5x5_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_5X5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_6x5_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_6X5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_6x6_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_6X6,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_8x5_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_8X5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_8x6_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_8X6,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_8x8_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_8X8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_10x5_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_10X5,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_10x6_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_10X6,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_10x8_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_10X8,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_10x10_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_10X10,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_12x10_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_12X10,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
    [PIPE_FORMAT_ASTC_12x12_SRGB] = {
        .czt = NVB097_SET_COLOR_TARGET_FORMAT_V_DISABLED,
        .support = NIL_FORMAT_SUPPORTS_TEXTURE_BIT,
        .tic_v2_data_type = NVCB97_TEXHEAD_V2_BL_DATA_TYPE_TEX_DATA_TYPE_UNORM,
        .tic = {
            .comp_sizes = NVB097_TEXHEAD_BL_COMPONENTS_SIZES_ASTC_2D_12X12,
            .type_r = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_g = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_b = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .type_a = NV9097_TEXHEADV2_0_R_DATA_TYPE_NUM_UNORM,
            .src_x = NV9097_TEXHEADV2_0_Z_SOURCE_IN_R,
            .src_y = NV9097_TEXHEADV2_0_Z_SOURCE_IN_G,
            .src_z = NV9097_TEXHEADV2_0_Z_SOURCE_IN_B,
            .src_w = NV9097_TEXHEADV2_0_Z_SOURCE_IN_A,
        },
    },
};
